@@ -7,7 +7,7 @@ import sys
 from .spectrum import SpectralRecord
 
 def parse_mb_file(file_name):
-    with open(file_name,'r') as f:
+    with open(file_name,'r', encoding="utf8", errors="ignore") as f:
         in_peaks = False
         peaks = []
         metadata = {}
@@ -16,6 +16,8 @@ def parse_mb_file(file_name):
         precursor_type = None
         smiles = None
         iupac = None
+        inchikey = None
+        polarity = None
         for line in f:
             if len(line) == 0:
                 continue
@@ -40,6 +42,9 @@ def parse_mb_file(file_name):
                 else:
                     precursor_type = precursor_type_string
 
+                continue
+            if line.startswith('AC$MASS_SPECTROMETRY: ION_MODE'):
+                polarity = line.split()[-1]
                 continue
             if line.startswith('CH$NAME'):
                 names.append(' '.join(line.split(':')[1:]))
@@ -50,6 +55,8 @@ def parse_mb_file(file_name):
             if line.startswith('CH$IUPAC'):
                 iupac = line.split()[-1]
                 continue
+            if line.startswith('CH$LINK: INCHIKEY'):
+                inchikey = line.split()[-1]
             if in_peaks:
                 if line.startswith('//'):
                     in_peaks = False
@@ -61,6 +68,8 @@ def parse_mb_file(file_name):
         metadata['smiles'] = smiles
         metadata['iupac'] = iupac
         metadata['names'] = names
+        metadata['inchikey'] = inchikey
+        metadata['polarity'] = polarity
         spectrum_id = file_name.split(os.sep)[-1].split('.')[0]
         record = SpectralRecord(precursor_mz,peaks,metadata,file_name,spectrum_id)
 
